"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* tslint:disable:max-file-line-count */
var expressPresenter_1 = require("xapi-statements/dist/expressPresenter");
var facade_1 = require("xapi-statements/dist/repo/facade");
var service_1 = require("xapi-statements/dist/service");
var en_1 = require("xapi-statements/dist/translatorFactory/en");
var config_1 = require("../config");
var logger_1 = require("../logger");
var tracker_1 = require("../tracker");
var getTranslatorFacade = function () {
    switch (config_1.default.lang) {
        case 'en':
        default:
            return en_1.default;
    }
};
var repo = facade_1.default({
    auth: {
        facade: config_1.default.repoFactory.authRepoName,
        fake: {},
        fetch: {
            llClientInfoEndpoint: config_1.default.fetchAuthRepo.llClientInfoEndpoint,
        },
        mongo: {
            url: config_1.default.mongoModelsRepo.url,
        },
    },
    events: {
        facade: config_1.default.repoFactory.eventsRepoName,
        redis: {
            prefix: config_1.default.redis.prefix,
            url: config_1.default.redis.url,
        },
    },
    models: {
        facade: config_1.default.repoFactory.modelsRepoName,
        memory: {
            state: {
                fullActivities: [],
                statements: [],
            },
        },
        mongo: {
            url: config_1.default.mongoModelsRepo.url,
        },
    },
    storage: {
        facade: config_1.default.repoFactory.storageRepoName,
        local: {
            storageDir: config_1.default.localStorageRepo.storageDir + "/" + config_1.default.storageSubFolders.statements,
        },
        s3: {
            awsConfig: config_1.default.s3StorageRepo.awsConfig,
            bucketName: config_1.default.s3StorageRepo.bucketName,
            subFolder: config_1.default.storageSubFolders.statements,
        },
    },
});
var service = service_1.default({
    awaitUpdates: config_1.default.statementsService.awaitUpdates,
    enableActivityUpdates: config_1.default.statementsService.enableActivityUpdates,
    enableAttachmentCreation: config_1.default.statementsService.enableAttachmentCreation,
    enableAttachmentValidation: config_1.default.statementsService.enableAttachmentValidation,
    enableConflictChecks: config_1.default.statementsService.enableConflictChecks,
    enableNullRemoval: config_1.default.statementsService.enableNullRemoval,
    enableReferencing: config_1.default.statementsService.enableReferencing,
    enableStatementCreation: config_1.default.statementsService.enableStatementCreation,
    enableVoiding: config_1.default.statementsService.enableVoiding,
    enableVoidingChecks: config_1.default.statementsService.enableVoidingChecks,
    logger: logger_1.default,
    repo: repo,
    tracker: tracker_1.default,
});
var presenter = expressPresenter_1.default({
    bodyParserLimit: config_1.default.express.bodyParserLimit,
    customRoute: 'xAPI/statements/status',
    customRouteText: 'ok',
    llClientInfoEndpoint: config_1.default.fetchAuthRepo.llClientInfoEndpoint,
    logger: logger_1.default,
    morganDirectory: config_1.default.express.morganDirectory,
    service: service,
    tracker: tracker_1.default,
    translator: getTranslatorFacade(),
});
exports.default = presenter;
//# sourceMappingURL=statements.js.map